# -*- coding: utf-8 -*-
"""
Created on April 13,  2022

@author: wang Haihua
"""

from importlib_metadata import entry_points
import numpy as np
from collections import Counter
import matplotlib.pyplot as plt
import math
plt.rcParams.update({'font.family': 'STIXGeneral', 'mathtext.fontset': 'stix'})

###########################################################################################
###############################     1 Queuing Theory        ###############################
###########################################################################################

####***************************     1.1 Normalization       ****************************###

def queue_p0(c,lam,mu):
    '''
    c: Number of service desks
    lam: Average rate of customer arrivals
    mu: Average rate of system services
    '''
    a1 = sum([1/math.factorial(k)*(lam/mu)**k for k in range(c)])
    a2 = (1/math.factorial(c))*(1/(1-lam/(c*mu))*(lam/mu)**c)
    return 1/(a1+a2)


def average_queue(c,lam,mu):
    '''
    c: Number of service desks
    lam: Average rate of customer arrivals
    mu: Average rate of system services
    '''
    p0 = queue_p0(c,lam,mu)
    rou = lam/(c*mu)
    b1 = (c*rou)**c*rou
    b2 = math.factorial(c)*(1-rou)**2
    return b1/b2*p0



from setuptools import setup, find_packages


setup(
    name='model-insight',
    version='0.3.12',
    license='MIT',
    author="Wang Haihua",
    author_email='reformship@gmail.com',
    description='A package for learning and teaching mathematical modeling',
    long_description='long description blabla',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    url='https://github.com/reformship/model-insight',
    keywords='mathematical modeling',
    install_requires=[
          'numpy','pandas','matplotlib'
      ],
    include_package_data=True,
    package_data={'': ['src/model_insight/datasets/*.csv','src/model_insight/datasets/*.xls','src/model_insight/datasets/*.xlsx']},

)
